@@ -1,15 +1,9 @@
 context("scales")
 test_that("scales work correctly", {
 
-  fill_scale <- scale_fill_viridis(option = "A")
-  expect_equal(fill_scale$scale_name, "gradientn")
-
   fill_scale <- scale_fill_viridis(option = "A", discrete = TRUE)
   expect_equal(fill_scale$is_discrete(), TRUE)
 
-  color_scale <- scale_color_viridis(option = "A")
-  expect_equal(color_scale$scale_name, "gradientn")
-
   color_scale <- scale_color_viridis(option = "A", discrete = TRUE)
   expect_equal(color_scale$is_discrete(), TRUE)
 
@@ -23,7 +17,7 @@ context("colorandfill")
 test_that("visual elements are correct", {
 
   skip_on_cran()
-  skip_if(getRversion() < 4.1)
+  skip_if(getRversion() < "4.1")
 
   library(ggplot2)
   library(MASS)
